@@ -1,26 +1,16 @@
 import os
 import cv2
 import glob
-import tqdm
 import argparse
 from lh_tool.Iterator import SingleProcess, MultiProcess
-import lh_tool.imageio as iio
+import imageio.v2 as iio
 
 
-def image2image(input_image_path, output_image_path, input_postfix, output_postfix, image_size=None):
-    image_file_list = glob.glob(os.path.join(input_image_path, f'*.{input_postfix}'))
-    if len(image_file_list) == 0:
-        return
-    output_image_path = input_image_path if output_image_path is None else output_image_path
-    os.makedirs(output_image_path, exist_ok=True)
-
-    for image_file in tqdm.tqdm(image_file_list):
-        filename = os.path.basename(image_file)
-        output_image_file = os.path.join(output_image_path, os.path.splitext(filename)[0] + f'.{output_postfix}')
-        image = iio.imread(image_file)
-        if image_size is not None:
-            image = cv2.resize(image, tuple(image_size))
-        iio.imwrite(output_image_file, image)
+def image2image(input_file, output_file, image_size=None):
+    image = iio.imread(input_file)
+    if image_size is not None:
+        image = cv2.resize(image, tuple(image_size))
+    iio.imwrite(output_file, image)
 
 
 def main():
@@ -37,22 +27,32 @@ def main():
     print(opts)
 
     try:
-        input_image_path = opts.input
-        output_image_path = opts.output
+        input_path = opts.input
+        output_path = opts.output
         input_postfix = opts.input_postfix
         output_postfix = opts.output_postfix
-        image_size = opts.size
+        image_size = None if opts.size is None else tuple(opts.size)
         recursive = opts.recursive
         nprocs = opts.nprocs
         if recursive:
-            image_path_list = glob.glob(os.path.join(opts.input, '*/'))
-            if nprocs == 1:
-                iterator = SingleProcess(image2image)
-            else:
-                iterator = MultiProcess(image2image, nprocs=nprocs)
-            iterator.run(image_path_list, None, input_postfix, output_postfix, image_size)
+            input_file_list = glob.glob(os.path.join(input_path, '**', f'*.{input_postfix}'), recursive=True)
         else:
-            image2image(input_image_path, output_image_path, input_postfix, output_postfix, image_size)
+            input_file_list = glob.glob(os.path.join(input_path, f'*.{input_postfix}'))
+        output_file_list = []
+        for input_file in input_file_list:
+            if output_path is not None:
+                filename = os.path.basename(input_file)
+                filename = os.path.splitext(filename)[0] + f'.{output_postfix}'
+                output_file = os.path.join(output_path, filename)
+            else:
+                output_file = os.path.splitext(input_file)[0] + f'.{output_postfix}'
+            output_file_list.append(output_file)
+
+        if nprocs == 1:
+            iterator = SingleProcess(image2image)
+        else:
+            iterator = MultiProcess(image2image, nprocs=nprocs)
+        iterator.run(input_file_list, output_file_list, image_size=image_size)
 
     except AssertionError as e:
         print(e)
